==> mgpcli-0.1.45.tar.gz: server/lib/www.dart <==
import 'dart:io';

import 'package:args/args.dart';
import 'package:jaguar/jaguar.dart';
import 'package:logging/logging.dart';

import 'src/controller/log_controller.dart';
import 'src/request_route.dart';
import 'src/utils/logger.dart';

final address = '127.0.0.1';
final port = 8080;

Future main(List<String> arguments) async {
  _logConfig();
  final parser = ArgParser()
    ..addOption('resource',  abbr: 'r', defaultsTo: '../build/web/')
    ..addOption('workspace',  abbr: 'w');
  ArgResults argResults = parser.parse(arguments);
  final dir = argResults['resource'];
  workspace = argResults['workspace'];
  final sites = Platform.script.resolve(dir).toFilePath();
  var dicExist =
      await Directory(Platform.script.resolve(sites).toFilePath()).exists();
  print('${Platform.script.resolve(sites).toFilePath()}');
  final server = Jaguar(address: address, port: port);
  requestHandler(server, sites, isWebBuild: dicExist);
  await server.serve();
  LoggerUtil.i('Serving on http://$address:$port');
}

void _logConfig() {
  //监听器能监听的范围
  Logger.root.level = Level.ALL;
  //日志监听器
  Logger.root.onRecord.listen((rec) {
    //rec的类为LogRecord
    print('${rec.level}::${rec.time}::${rec.message}');
    logToClient(rec.level.name, rec.message, rec.time);
  });
}

void requestHandler(Jaguar server, String path, {bool isWebBuild}) async {
  print('isWebBuild=$isWebBuild');
  server.onException.add((ctx, e, trace) {
    LoggerUtil.i(e.toString()); //错误处理
  });
  server.before.add((ctx) {
    LoggerUtil.i(
        'Req => Method: ${ctx.method} Url: ${ctx.uri} Param:${ctx.query}');
  });

  server.after.add((ctx) {
    LoggerUtil.i('Response => Url: ${ctx.uri} Response:${ctx.response.value}');
    ctx.response.headers.add('Access-Control-Allow-Origin', '*'); //添加跨域支持
  });

  handleController(server, path, isWebBuild);
}

==> mgpcli-0.1.51.tar.gz: server/lib/www.dart <==
import 'dart:io';

import 'package:args/args.dart';
import 'package:jaguar/jaguar.dart';
import 'package:logging/logging.dart';

import 'src/controller/log_controller.dart';
import 'src/request_route.dart';
import 'src/utils/logger.dart';

final address = '127.0.0.1';
final port = 8080;

Future main(List<String> arguments) async {
  _logConfig();
  final parser = ArgParser()
    ..addOption('resource',  abbr: 'r', defaultsTo: '../build/web/')
    ..addOption('workspace',  abbr: 'w');
  ArgResults argResults = parser.parse(arguments);
  final dir = argResults['resource'];
  workspace = argResults['workspace'];
  final sites = Platform.script.resolve(dir).toFilePath();
  var dicExist =
      await Directory(Platform.script.resolve(sites).toFilePath()).exists();
  print('${Platform.script.resolve(sites).toFilePath()}');
  final server = Jaguar(address: address, port: port);
  requestHandler(server, sites, isWebBuild: dicExist);
  await server.serve();
  LoggerUtil.i('Serving on http://$address:$port');
}

void _logConfig() {
  //监听器能监听的范围
  Logger.root.level = Level.ALL;
  //日志监听器
  Logger.root.onRecord.listen((LogRecord rec) {
    print('${rec.level}::${rec.time}::${rec.message}');
    var name = rec.level.value >= Level.SEVERE.value ? "ERROR" : rec.level.name;
    logToClient(name, rec.message, rec.time);
  });
}

void requestHandler(Jaguar server, String path, {bool isWebBuild}) async {
  print('isWebBuild=$isWebBuild');
  server.onException.add((ctx, e, trace) {
    LoggerUtil.i(e.toString()); //错误处理
  });
  server.before.add((ctx) {
    LoggerUtil.i(
        'Req => Method: ${ctx.method} Url: ${ctx.uri} Param:${ctx.query}');
  });

  server.after.add((ctx) {
    LoggerUtil.i('Response => Url: ${ctx.uri} Response:${ctx.response.value}');
    ctx.response.headers.add('Access-Control-Allow-Origin', '*'); //添加跨域支持
  });

  handleController(server, path, isWebBuild);
}
